<?php
/**********************************************************************************
* XMLout.php                                                                      *
***********************************************************************************
* Simple XML Output Class                                                         *
* =============================================================================== *
* Software Version:           XSSI 1.0                                            *
* Software by:                Don Bauer - dgbauer@bauerbox.com                    *
* License:                    GPL 2.0                                             *
**********************************************************************************/
class XMLout
{
	var		$bc	=	false;
	var		$wo =	false;

	// Completed April 13, 2007
	// Adds a tag to XML output
	function tagAdd($index = '', $value = '')
	{
		// Check if $value is a boolean variable first...
		if(is_bool($value))
		{
			if($value)
			{
				$value = "true";
			} else {
				$value = "false";
			}
		}
		$out = '';
		if($index == '')
		{
			$out .= '<err>tagAdd() was called incorrectly</err>
';
		} else if ($index == 'nest_open') {
			$out .= '<'.$value.'>
';
		} else if ($index == 'nest_close') {
			$out .= '</'.$value.'>
';
		} else {
			$out .= '<'.$index.'><![CDATA['.$value.']]></'.$index.'>
';
		}
		return $out;
	}
	
	// Completed April 13, 2007
	// Adds error information to XML output
	function error($msg = "", $file = null, $line = null)
	{
		if ($msg == "") $msg = "There was an error in script processing";
		$out = $this->tagAdd("err",$msg);
		if ($file != null)
		{
			$out .= $this->tagAdd("err_file",$file);
		}
		if ($line != null)
		{
			$out .= $this->tagAdd("err_line",$line);
		}
		return $out;
	}
	
	// Completed April 13, 2007
	// Adds debug information to XML output
	function debug($msg = "", $file = null, $line = null)
	{
		if ($msg == "") $msg = "There was an error in script processing";
		$out = $this->tagAdd("debug",$msg);
		if ($file != null)
		{
			$out .= $this->tagAdd("debug_file",$file);
		}
		if ($line != null)
		{
			$out .= $this->tagAdd("debug_line",$line);
		}
		return $out;
	}
	
	function arrayToXML($array, $name = "broadcast")
	{
		// Check to make sure we got an array back
		if (!is_array($array))
		{
			// Uh-oh, this isn't an array.  Return error.
			// return $this->error("arrayToXML() did not recieve an array!");
			if ($name != "broadcast")
			{
				if (!$this->bc)
				{
					$out = $this->tagAdd("nest_open","broadcast");
					$out .= $this->tagAdd($name, $array);
					$out .= $this->tagAdd("nest_close","broadcast");
					$this->bc = true;
				} else {
					$out = $this->tagAdd($name, $array);
				}
			} else {
				return $this->error("arrayToXML() did not recieve an array!");
			}
		} else {
			// Yay! We got an array!  Let's do stuff with it!
			if(is_int($name) || (($_GET['a'] == "whosOnline" || $_GET['a'] == "logOnline") && $name != "broadcast"))
			{
				if(isset($_GET['a']))
				{
					// Set name's accordingly :-D
					switch ($_GET['a'])
					{
						case "topBoards":
							$name = "board";
							break;
						case "topPoster":
							$name = "poster";
							break;
						case "boardNews":
							$name = "board";
							break;
						case "whosOnline":
							if ($this->wo) 
							{
								$name = "onlineMember";
							} else {
								// Do nothing
								$this->wo = true;
							}
							break;
						case "logOnline":
							if ($this->wo) 
							{
								$name = "onlineMember";
							} else {
								// Do nothing
								$this->wo = true;
							}
							break;
						case "topTopicsViews":
							$name = "topic";
							break;
						case "topTopicsReplies":
							$name = "topic";
							break;
						case "recentTopics":
							$name = "topic";
							break;
						case "recentPosts":
							$name = "post";
							break;
						case "todaysBirthdays":
							$name = "birthday";
							break;
						case "todaysHolidays":
							$name = "holiday";
							break;
						case "todaysEvents":
							$name = "event";
							break;
						case "todaysCalendar":
							$name = "calendar";
							break;
						case "recentEvents":
							$name = "event";
							break;
						default:
							$name = "subcast";
							break;
					}
				} else {
					$name = "subcast";
				}
			}
			$out = $this->tagAdd("nest_open",$name);
			foreach ($array as $index => $value)
			{
				// OK, let's check for a nested array
				if (!is_array($value))
				{
					// $value isn't an array, let's output the tag
					$out .= $this->tagAdd($index,$value);
				} else {
					// $value is an array, let's recursively evaluate it! ;)
					$out .= $this->arrayToXML($value,$index);
				}
			}
			$out .= $this->tagAdd("nest_close",$name);
		}
		return $out;
	}
}
?>